Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/httpserver_simpletest.py
    :caption: examples/httpserver_simpletest.py
    :linenos:

Temperature test
--------------------

Send the microcontroller temperature back to the browser with this simple test.

.. literalinclude:: ../examples/httpserver_temperature.py
    :caption: examples/httpserver_temperature.py
    :linenos:

Simple polling test
-------------------

If you want your code to do more than just serve web pages,
use the start/poll methods as shown in this example.

.. literalinclude:: ../examples/httpserver_simplepolling.py
    :caption: examples/httpserver_simplepolling.py
    :linenos:
